Examples
========

The examples in this section are intended to give in depth overviews
of how to accomplish specific tasks with MongoDB and PyMongo.

Unless otherwise noted, all examples assume that a MongoDB instance is
running on the default host and port. Assuming you have `downloaded
and installed <http://www.mongodb.org/display/DOCS/Getting+Started>`_
MongoDB, you can start it like so:

.. code-block:: bash

  $ mongod

.. toctree::
   :maxdepth: 1

   aggregation
   authentication
   copydb
   bulk
   custom_type
   datetimes
   geo
   gevent
   gridfs
   high_availability
   mod_wsgi
   tls
